from io import open

from setuptools import find_packages, setup

version = '0.6.0'

with open('README.md', 'r', encoding='utf-8') as f:
    readme = f.read()

setup(
    name='monitor_summer_snapshots',
    version=version,
    description='Scan summer volumes and get snapshots sizes. Report the numbers in various storage systems (currently influxdb and zabbix supported)',
    long_description_content_type='text/markdown',
    long_description=readme,
    author='Jonathan Schaeffer',
    author_email='jonathan.schaeffer@univ-grenoble-alpes.fr',
    maintainer='Jonathan Schaeffer',
    maintainer_email='jonathan.schaeffer@univ-grenoble-alpes.fr',
    url='https://gricad-gitlab.univ-grenoble-alpes.fr/schaeffj/monitoring-summer-snapshot',
    license='GPLv3',
    entry_points={
        'console_scripts': ['monitor_summer_snapshots = monitor_summer_snapshots:main']
    },

    data_files=[('/etc/monitor_summer_snapshots/',[
        'monitor_summer_snapshots/config.yml.example',
        'monitor_summer_snapshots/logger.conf',
        'monitor_summer_snapshots/zabbix_discovery.py'
    ]),
               ('doc',['monitor_summer_snapshots/graphana_dashboard.json','monitor_summer_snapshots/zabbix_template.xml'])
    ],
    keywords=[
        'monitoring',
    ],

    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
    ],

    install_requires=["pyyaml", "influxdb", "py-zabbix", "paramiko"],
    tests_require=['coverage', 'pytest'],

    packages=find_packages(),
)
